@@ -16,6 +16,8 @@ import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_elasticloadbalancingv2._jsii
+import aws_cdk.aws_elasticloadbalancingv2_targets._jsii
 import aws_cdk.aws_elasticsearch._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_glue._jsii
@@ -43,9 +45,9 @@ import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/core",
-    "1.125.0",
+    "1.126.0",
     __name__[0:-6],
-    "core@1.125.0.jsii.tgz",
+    "core@1.126.0.jsii.tgz",
 )
 
 __all__ = [
